@@ -26,25 +26,25 @@ C<Sys::User::Group> is the class for an entry of the group database.
 
 =head2 gr_name
 
-  method gr_name : string ();
+C<method gr_name : string ();>
 
 Get the group name.
 
 =head2 gr_passwd
 
-  method gr_passwd : string ();
+C<method gr_passwd : string ();>
 
 Get the group password.
 
 =head2 gr_gid
 
-  method gr_gid : int ();
+C<method gr_gid : int ();>
 
 Get the group ID.
 
 =head2 gr_mem
 
-  method gr_mem : string[] ();
+C<method gr_mem : string[] ();>
 
 Get the group member names.
 
